<?php

declare(strict_types=1);

namespace Dedi\SyliusBannerPlugin\Twig;

use Dedi\SyliusBannerPlugin\Repository\AlertMessageRepositoryInterface;
use Dedi\SyliusBannerPlugin\Services\ClockInterface;
use Twig\Extension\AbstractExtension;
use Twig\TwigFunction;

final class AlertMessageRetrieverExtension extends AbstractExtension
{
    private ClockInterface $clock;

    private AlertMessageRepositoryInterface $alertMessageRepository;

    public function __construct(
        ClockInterface $clock,
        AlertMessageRepositoryInterface $alertMessageRepository
    ) {
        $this->clock = $clock;
        $this->alertMessageRepository = $alertMessageRepository;
    }

    public function getFunctions(): array
    {
        return [
            new TwigFunction(
                'dedi_banner_retrieve_available_alert_messages',
                fn (): array => $this->alertMessageRepository->getAvailableAlertMessages($this->clock->getDateTimeImmutable())
            ),
            new TwigFunction(
                'dedi_banner_retrieve_available_basket_alert_messages',
                fn (): array => $this->alertMessageRepository->getAvailableBasketAlertMessages($this->clock->getDateTimeImmutable())
            ),
        ];
    }
}
